@@ -24,6 +24,10 @@ if [ "$USE_CONDA" = "true" ]; then
         conda install pyzmq=19
     fi
 
+    # Constrain jupyter_client version on conda based tests
+    # The actual dependency constrain is done in spyder-kernels since v2.1.1
+    conda install jupyter_client=6
+
     # Remove packages we have subrepos for.
     conda remove spyder-kernels --force -q -y
     conda remove python-lsp-server --force -q -y
@@ -52,8 +56,6 @@ else
     pip uninstall python-lsp-server -q -y
     pip uninstall qdarkstyle -q -y
 
-    # Install jupyter-client 6 until we release spyder-kernels 2.1.1
-    pip install jupyter-client==6.1.12
 fi
 
 # Install subrepos in development mode
