@@ -44,7 +44,7 @@ ASSETS_URL = os.environ.get(
     'releases/download/0.0.1/assets.zip')
 
 # Packages to remove from the requirements for example pip or
-# external direct dependencies (python-language-server spyder-kernels)
+# external direct dependencies (python-lsp-server spyder-kernels)
 
 UNWANTED_PACKAGES = os.environ.get('UNWANTED_PACKAGES', '').split()
 
@@ -55,12 +55,12 @@ SKIP_PACKAGES = os.environ.get('SKIP_PACKAGES', '').split()
 
 # Packages to be added to the packages section regardless wheel checks or
 # packages skipped, for example external direct dependencies
-# (spyder-kernels python-language-server)
+# (spyder-kernels python-lsp-server)
 
 ADD_PACKAGES = os.environ.get('ADD_PACKAGES', '').split()
 
 # Packages to be installed using the editable flag
-# (python-language-server in PRs)
+# (python-lsp-server in PRs)
 
 INSTALL_EDITABLE_PACKAGES = os.environ.get(
     'INSTALL_EDITABLE_PACKAGES', '').split()
@@ -101,6 +101,7 @@ packages=
 files={package_dist_info} > $INSTDIR/pkgs
     black-20.8b1.dist-info > $INSTDIR/pkgs
     __main__.py > $INSTDIR/pkgs/jedi/inference/compiled/subprocess
+    __init__.py > $INSTDIR/pkgs/pylint
     lib
     tcl86t.dll > $INSTDIR/pkgs
     tk86t.dll > $INSTDIR/pkgs
@@ -353,6 +354,11 @@ def run(python_version, bitness, repo_root, entrypoint, package, icon_path,
                 "installers/Windows/assets/jedi/__main__.py",
                 os.path.join(work_dir, "__main__.py"))
 
+            print("Copying patched __init__.py for Pylint")
+            shutil.copy(
+                "installers/Windows/assets/pylint/__init__.py",
+                os.path.join(work_dir, "__init__.py"))
+
             print("Copying required assets for Tkinter to work")
             shutil.copytree(
                 "installers/Windows/assets/tcl/lib",
