@@ -71,7 +71,7 @@ class CompletionPlugin(SpyderPluginV2):
     NAME = 'completions'
     CONF_SECTION = 'completions'
     REQUIRES = [Plugins.Preferences]
-    OPTIONAL = [Plugins.StatusBar, Plugins.MainMenu]
+    OPTIONAL = [Plugins.Application, Plugins.StatusBar, Plugins.MainMenu]
 
     CONF_FILE = False
 
@@ -292,6 +292,12 @@ class CompletionPlugin(SpyderPluginV2):
         for sb in container.all_statusbar_widgets():
             self.statusbar.add_status_widget(sb)
 
+    @on_plugin_available(plugin=Plugins.Application)
+    def on_application_available(self):
+        application = self.get_plugin(Plugins.Application)
+        self.sig_restart_requested.connect(
+            application.sig_restart_requested)
+
     @on_plugin_available(plugin=Plugins.MainMenu)
     def on_mainmenu_available(self):
         main_menu = self.get_plugin(Plugins.MainMenu)
